.. currentmodule:: sardana.tango.pool.Pool

:mod:`~sardana.tango.pool.Pool`
=========================================

.. automodule:: sardana.tango.pool.Pool

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`Pool`
    * :class:`PoolClass`

Pool
-------

.. inheritance-diagram:: Pool
    :parts: 1
    
.. autoclass:: Pool
    :show-inheritance:
    :members:
    :undoc-members:

PoolClass
-----------

.. inheritance-diagram:: PoolClass
    :parts: 1
    
.. autoclass:: PoolClass
    :show-inheritance:
    :members:

